[][src]Struct tweetust::clients::DirectMessagesClient

pub struct DirectMessagesClient<'a, A: 'a + Authenticator, H: 'a + HttpHandler> { /* fields omitted */ }

Provides a set of methods for the wrapper of GET/POST direct_messages.

Methods

impl<'a, A: Authenticator, H: HttpHandler> DirectMessagesClient<'a, A, H>[src]

pub fn received(&self) -> DirectMessagesReceivedRequestBuilder<'a, A, H>[src]

Returns the most recent direct messages sent to the authenticating user.

pub fn sent(&self) -> DirectMessagesSentRequestBuilder<'a, A, H>[src]

Returns the most recent direct messages sent by the authenticating user.

pub fn show(&self, id: i64) -> DirectMessagesShowRequestBuilder<'a, A, H>[src]

Returns a single direct message, specified by an id parameter.

pub fn new<T1: Into<Cow<'a, str>>>(
    &self,
    text: T1
) -> DirectMessagesNewRequestBuilder<'a, A, H>
[src]

Sends a new direct message to the specified user from the authenticating user.

pub fn destroy(&self, id: i64) -> DirectMessagesDestroyRequestBuilder<'a, A, H>[src]

Destroys the direct message specified in the required ID parameter.